'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.user = exports.token = exports.webPort = exports.serverPort = exports.serverHost = exports.serverAddress = exports.device = undefined;

var _fs = require('fs');

var _minimistArgv = require('minimist-argv');

var _minimistArgv2 = _interopRequireDefault(_minimistArgv);

var _detectBoard = require('./utils/detectBoard');

var _detectBoard2 = _interopRequireDefault(_detectBoard);

var _parseHostPort = require('./utils/parseHostPort');

var _parseHostPort2 = _interopRequireDefault(_parseHostPort);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const device = exports.device = (0, _detectBoard2.default)();

const serverAddress = exports.serverAddress = process.env.SERVER_ADDRESS || _minimistArgv2.default.address || `${process.env.SERVER_HOST || _minimistArgv2.default.host}:${process.env.SERVER_PORT || _minimistArgv2.default.port}`;
const [serverHost, serverPort] = (0, _parseHostPort2.default)(serverAddress);

exports.serverHost = serverHost;
exports.serverPort = serverPort;


const tokenFromFile = (() => {
  try {
    return (0, _fs.readFileSync)('/etc/pooliot-client/pooliot_token.txt', 'utf-8').trim();
  } catch (e) {
    return null;
  }
})();

const webPort = exports.webPort = process.env.WEB_PORT || _minimistArgv2.default['web-port'] || 80;
const token = exports.token = process.env.TOKEN || _minimistArgv2.default.token || tokenFromFile || process.env.USER_ID || _minimistArgv2.default.userId;

const guessUser = () => {
  if (!device.user) throw new Error('Please provide USER');
  return device.user;
};

const user = exports.user = process.env.USER !== 'root' && process.env.USER || process.env.PI_USER || _minimistArgv2.default.piUser || guessUser();

if (!serverAddress || serverAddress === ':') {
  // eslint-disable-next-line no-console
  console.log('WARNING: address is missing');
}

if (!token) {
  // eslint-disable-next-line no-console
  console.log('WARNING: userId is missing');
}
//# sourceMappingURL=params.js.map