import { readFileSync } from 'fs';
import argv from 'minimist-argv';
import detectBoard from './utils/detectBoard';
import parseHostPort from './utils/parseHostPort';

export const device = detectBoard();

export const serverAddress =
  process.env.SERVER_ADDRESS ||
  argv.address ||
  `${process.env.SERVER_HOST || argv.host}:${process.env.SERVER_PORT || argv.port}`;
const [serverHost, serverPort] = parseHostPort(serverAddress);

export { serverHost, serverPort };

const tokenFromFile = (() => {
  try {
    return readFileSync('/etc/pooliot-client/pooliot_token.txt', 'utf-8').trim();
  } catch (e) {
    return null;
  }
})();

export const webPort = process.env.WEB_PORT || argv['web-port'] || 80;
export const token =
  process.env.TOKEN || argv.token || tokenFromFile || process.env.USER_ID || argv.userId;

const guessUser = () => {
  if (!device.user) throw new Error('Please provide USER');
  return device.user;
};

export const user =
  (process.env.USER !== 'root' && process.env.USER) ||
  process.env.PI_USER ||
  argv.piUser ||
  guessUser();

if (!serverAddress || serverAddress === ':') {
  // eslint-disable-next-line no-console
  console.log('WARNING: address is missing');
}

if (!token) {
  // eslint-disable-next-line no-console
  console.log('WARNING: userId is missing');
}
